'use client';
import { signInWithApple } from '@/lib/actions';
import { StatusMessage, SubmitButton } from '@/components/default';
import { useAuth } from '@/components/context/auth';
import { useRouter } from 'next/navigation';
import { useState } from 'react';
import Image from 'next/image';

export const SignInWithApple = () => {
  const router = useRouter();
  const { isLoading, refreshUserData } = useAuth();
  const [statusMessage, setStatusMessage] = useState('');
  const [isSigningIn, setIsSigningIn] = useState(false);

  const handleSignInWithApple = async (e: React.FormEvent) => {
    e.preventDefault();
    try {
      setStatusMessage('');
      setIsSigningIn(true);
      
      const result = await signInWithApple();
      
      if (result?.success && result.data) {
        // Redirect to Apple OAuth page
        window.location.href = result.data;
      } else {
        setStatusMessage(`Error: ${result.error}`);
      }
    } catch (error) {
      setStatusMessage(
        `Error: ${error instanceof Error ? error.message : 'Could not sign in!'}`
      );
    } finally {
      setIsSigningIn(false);
      await refreshUserData();
      router.push('');
    }
  };

  return (
    <form onSubmit={handleSignInWithApple}>
      <SubmitButton
        className='w-full cursor-pointer'
        disabled={isLoading || isSigningIn}
        pendingText='Redirecting...'
        type="submit"
      >
        <div className='flex items-center gap-3'>
          <Image src='/icons/apple.png' alt='Apple logo' className='text-white' width={20} height={20} />
          <p>Sign in with Apple</p>
        </div>
      </SubmitButton>
      {statusMessage && (
        <StatusMessage message={{ error: statusMessage }} />
      )}
    </form>
  );
};
